@@ -1,6 +1,6 @@
 package FFI::Raw;
 {
-  $FFI::Raw::VERSION = '0.01';
+  $FFI::Raw::VERSION = '0.02';
 }
 
 use strict;
@@ -15,7 +15,7 @@ FFI::Raw - Raw FFI library for Perl
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -32,14 +32,16 @@ version 0.01
 =head1 DESCRIPTION
 
 B<FFI::Raw> provides a raw foreign function interface for Perl. It can access
-and call functions exported by shared libraries without the need to write a
-single line of XS code.
+and call functions exported by shared libraries without the need to write C/XS
+code. Dynamic symbols are automatically resolved at runtime so that the only
+information needed to use B<FFI::Raw> is the name (or path) of the target
+library, the name of the function to call and its signature.
 
 B<Attention>: this is experimental code, use at your own risk
 
 =head1 METHODS
 
-=head2 new($library, $function, $return_type [, $arg_type ...])
+=head2 new( $library, $function, $return_type [, $arg_type ...] )
 
 Create a new C<FFI::Raw> object. It loads C<$library>, finds the function
 C<$function> with return type C<$return_type> and creates a calling interface.
@@ -53,7 +55,7 @@ sub new  { FFI::Raw::_ffi_raw_new(@_)  }
 
 sub DESTROY { FFI::Raw::_ffi_raw_destroy(shift) }
 
-=head2 $self -> call([$arg ...])
+=head2 call( [$arg ...] )
 
 Execute the C<FFI::Raw> function C<$self>. This function takes also a variable
 number of arguments, which are passed to the called function. The argument types
@@ -63,6 +65,8 @@ must match the types passed to C<new>.
 
 sub call { FFI::Raw::_ffi_raw_call(@_) }
 
+=head1 TYPES
+
 =head2 FFI::Raw::void
 
 Return a FFI::Raw void type.
@@ -79,6 +83,14 @@ Return a FFI::Raw integer type.
 
 sub int    { ord 'i' };
 
+=head2 FFI::Raw::uint
+
+Return a FFI::Raw unsigned integer type.
+
+=cut
+
+sub uint    { ord 'I' };
+
 =head2 FFI::Raw::char
 
 Return a FFI::Raw char type.
@@ -87,6 +99,14 @@ Return a FFI::Raw char type.
 
 sub char   { ord 'c' };
 
+=head2 FFI::Raw::uchar
+
+Return a FFI::Raw unsigned char type.
+
+=cut
+
+sub uchar   { ord 'C' };
+
 =head2 FFI::Raw::float
 
 Return a FFI::Raw float type.
